@@ -54,7 +54,7 @@ def json2geodf(
     if in_crs != crs:
         geodf = geodf.to_crs(crs)
 
-    return geodf
+    return geodf.drop_duplicates()
 
 
 def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) -> Dict[str, Any]:
